==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/DamselflyModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.DamselflyAnimation;
import net.invictusslayer.slayersbeasts.world.entity.Damselfly;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class DamselflyModel<T extends Damselfly> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "damselfly_model"), "main");
	private final class_630 root;

	public DamselflyModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_43782(entity.flyAnimationState, DamselflyAnimation.FLY, ageInTicks, 10);
		method_43782(entity.perchAnimationState, DamselflyAnimation.PERCH, ageInTicks, 1.5F);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 19).method_32098(-2.0F, 0.0F, -6.0F, 3.0F, 2.0F, 6.0F, new class_5605(0.0F))
				.method_32101(18, 19).method_32098(-1.5F, -1.0F, -6.0F, 2.0F, 1.0F, 6.0F, new class_5605(0.0F))
				.method_32101(0, 8).method_32098(-1.5F, 0.0F, -8.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 4).method_32098(-2.75F, -0.5F, -8.5F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-0.25F, -0.5F, -8.5F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-1.5F, -0.5F, 0.0F, 2.0F, 2.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32090(0.5F, 22.0F, -2.0F));

		class_5610 wing_left_front = body.method_32117("wing_left_front", class_5606.method_32108().method_32101(0, 15).method_32098(0.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -1.0F, -4.75F, 0.0F, 0.1745F, 0.0F));

		class_5610 wing_left_hind = body.method_32117("wing_left_hind", class_5606.method_32108().method_32101(13, 8).method_32098(0.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -0.5F, -2.25F, 0.0F, -0.1745F, 0.0F));

		class_5610 wing_right_front = body.method_32117("wing_right_front", class_5606.method_32108().method_32101(13, 4).method_32098(-15.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -1.0F, -4.75F, 0.0F, -0.1745F, 0.0F));

		class_5610 wing_right_hind = body.method_32117("wing_right_hind", class_5606.method_32108().method_32101(13, 0).method_32098(-15.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -0.5F, -2.25F, 0.0F, 0.1745F, 0.0F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/DamselflyModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.DamselflyAnimation;
import net.invictusslayer.slayersbeasts.client.state.DamselflyRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class DamselflyModel extends class_583<DamselflyRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "damselfly_model"), "main");

	public DamselflyModel(class_630 root) {
		super(root);
	}

	public void setupAnim(DamselflyRenderState state) {
		super.method_2819(state);
		method_62099(state.flyAnimationState, DamselflyAnimation.FLY, state.field_53328, 10);
		method_62099(state.perchAnimationState, DamselflyAnimation.PERCH, state.field_53328, 1.5F);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 19).method_32098(-2.0F, 0.0F, -6.0F, 3.0F, 2.0F, 6.0F, new class_5605(0.0F))
				.method_32101(18, 19).method_32098(-1.5F, -1.0F, -6.0F, 2.0F, 1.0F, 6.0F, new class_5605(0.0F))
				.method_32101(0, 8).method_32098(-1.5F, 0.0F, -8.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 4).method_32098(-2.75F, -0.5F, -8.5F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-0.25F, -0.5F, -8.5F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-1.5F, -0.5F, 0.0F, 2.0F, 2.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32090(0.5F, 22.0F, -2.0F));

		class_5610 wing_left_front = body.method_32117("wing_left_front", class_5606.method_32108().method_32101(0, 15).method_32098(0.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -1.0F, -4.75F, 0.0F, 0.1745F, 0.0F));

		class_5610 wing_left_hind = body.method_32117("wing_left_hind", class_5606.method_32108().method_32101(13, 8).method_32098(0.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -0.5F, -2.25F, 0.0F, -0.1745F, 0.0F));

		class_5610 wing_right_front = body.method_32117("wing_right_front", class_5606.method_32108().method_32101(13, 4).method_32098(-15.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -1.0F, -4.75F, 0.0F, -0.1745F, 0.0F));

		class_5610 wing_right_hind = body.method_32117("wing_right_hind", class_5606.method_32108().method_32101(13, 0).method_32098(-15.0F, 0.0F, -1.0F, 15.0F, 0.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -0.5F, -2.25F, 0.0F, 0.1745F, 0.0F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}
